# Algorithm 2

## Getting Started

1. We will use Python version 3.10.4. Please install this on your device and either set it as your default or put it into a virtual environment and activate your virtual environment.
2. Run `pip install -r requirements.txt` to install all pip packages used in this project.

## Tools

### `ProcessData`
To run ProcessData:
```
python3 ProcessData.py
```

## Important Links
- [Communication Standards](https://www.overleaf.com/read/djvkdxpyrtxd)
- [Coding Standards](https://www.overleaf.com/read/zrgztvyfngdk)
- [Project Board](https://github.com/orgs/seng499-company1/projects/6/)
- [Algorithm 1 Data Model](https://docs.google.com/document/d/163L7pv6w5Z38rUrl2EwRJq-A9ZLllCIO9uYbUkdxi2s/edit?usp=sharing)
- [Algorithm 2 Data Model](https://docs.google.com/document/d/14kvPrWQTaWBeyqnaRp2-NkLqod5pwzMYE8cXo7f6kQ4/edit?usp=sharing)
